aboutsummaryrefslogtreecommitdiff
path: root/src/lib/krb5/ccache/stdio/scc_read.c
diff options
context:
space:
mode:
authorChris Provenzano <proven@mit.edu>1995-09-06 19:13:02 +0000
committerChris Provenzano <proven@mit.edu>1995-09-06 19:13:02 +0000
commit01ea1dbbef0647e890c9cb615e31586877cd98fd (patch)
tree59e90cd7ccb0927645cb76b2905e3d072d0337fe /src/lib/krb5/ccache/stdio/scc_read.c
parentb87504a2015b9bf55148c31757137cfb2245b1b5 (diff)
downloadkrb5-01ea1dbbef0647e890c9cb615e31586877cd98fd.zip
krb5-01ea1dbbef0647e890c9cb615e31586877cd98fd.tar.gz
krb5-01ea1dbbef0647e890c9cb615e31586877cd98fd.tar.bz2
* scc_read.c, scc_write.c : s/keytype/enctype/g, s/KEYTYPE/ENCTYPE/g
git-svn-id: svn://anonsvn.mit.edu/krb5/trunk@6723 dc483132-0cff-0310-8789-dd5450dbe970
Diffstat (limited to 'src/lib/krb5/ccache/stdio/scc_read.c')
-rw-r--r--src/lib/krb5/ccache/stdio/scc_read.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/krb5/ccache/stdio/scc_read.c b/src/lib/krb5/ccache/stdio/scc_read.c
index 633e9e1..de29794 100644
--- a/src/lib/krb5/ccache/stdio/scc_read.c
+++ b/src/lib/krb5/ccache/stdio/scc_read.c
@@ -197,12 +197,12 @@ krb5_scc_read_keyblock(context, id, keyblock)
keyblock->contents = 0;
kret = krb5_scc_read_ui_2(context, id, &ui2);
- keyblock->keytype = ui2;
+ keyblock->enctype = ui2;
CHECK(kret);
if (data->version == KRB5_SCC_FVNO_3) {
/* This works because the old etype is the same as the new keytype. */
kret = krb5_scc_read_ui_2(context, id, &ui2);
- keyblock->keytype = ui2;
+ keyblock->enctype = ui2;
CHECK(kret);
}
@@ -197,12 +197,12 @@ krb5_scc_read_keyblock(context, id, keyblock)
CHECK(kret);
if (data->version == KRB5_SCC_FVNO_3) {
- /* This works because the old etype is the same as the new keytype. */
+ /* This works because the old etype is the same as the new enctype. */
kret = krb5_scc_read_ui_2(context, id, &ui2);